module TripAdvisor
  class ResourceManager
    attr_accessor :api_client, :output_dir
  
    def initialize(options={})
      options.each { |k,v| self.send("#{k}=", v) }
    end
  
    def locales
      @locales ||= api_client.get_flights_locales
    end
  
    def dump_airports
      provision_locale_projects
      puts "Dumping Airport fixtures for #{locales.size} locales..."
      locales.each do |locale|
        locale_identifier = locale['locale']
        begin
          json = api_client.get(:airports, locale: locale_identifier)
        rescue RestClient::Exception => ex
           puts "ERROR: Failed Fetching Airports fixture for '#{locale_identifier}' locale_identifier: #{ex}"
           next
        end
        language_code = TripAdvisor::Translation.locale_identifier_to_language_codes_mapping[locale_identifier] || locale_identifier
        path = File.join(output_dir, "#{language_code}.lproj", "airports.json")
        File.open(path, 'w') { |f| f << json }
        puts "  Wrote Airports fixture for '#{locale_identifier}' locale to #{path}"
      end            
    end
  
    def dump_airlines
      provision_locale_projects
      puts "Dumping Airline fixtures for #{locales.size} locales..."
      locales.each do |locale|
        locale_identifier = locale['locale']
        begin
          json = api_client.get(:airlines, locale: locale_identifier)
        rescue RestClient::Exception => ex
           puts "ERROR: Failed Fetching Airlines fixture for '#{locale_identifier}' locale_identifier: #{ex}"
           next
        end
        language_code = TripAdvisor::Translation.locale_identifier_to_language_codes_mapping[locale_identifier] || locale_identifier
        path = File.join(output_dir, "#{language_code}.lproj", "airlines.json")
        File.open(path, 'w') { |f| f << json }
        puts "  Wrote Airlines fixture for '#{locale_identifier}' locale to #{path}"
      end
    end
  
    def dump_purchase_link_providers
      provision_locale_projects
      puts "Dumping Purchase Link Provider fixtures for #{locales.size} locales..."
      locales.each do |locale|
        locale_identifier = locale['locale']
        begin
          json = api_client.get(:flight_purchase_link_providers, locale: locale_identifier)
        rescue RestClient::Exception => ex
           puts "ERROR: Failed Fetching Purchase Link Provider fixture for '#{locale_identifier}' locale_identifier: #{ex}"
           next
        end
        language_code = TripAdvisor::Translation.locale_identifier_to_language_codes_mapping[locale_identifier] || locale_identifier
        path = File.join(output_dir, "#{language_code}.lproj", "flight_purchase_link_providers.json")
        File.open(path, 'w') { |f| f << json }
        puts "  Wrote Purchase Link Provider fixture for '#{locale_identifier}' locale to #{path}"
      end
    end

    def language_tags_from_locales_api
      locales.map { |l| l['locale'] }
    end

    def provision_locale_projects(language_tags = self.language_tags_from_locales_api)
      FileUtils.mkdir(output_dir) unless File.exists?(output_dir)
      language_tags.inject([]) do |paths, language_tag|
        language_tag = TripAdvisor::Translation.locale_identifier_to_language_codes_mapping[language_tag] || language_tag
        path = File.join(output_dir, "#{language_tag}.lproj")
        unless File.exist?(path)
          FileUtils.mkdir(path)
          paths << path
          yield path if block_given?
        end      
        paths
      end
    end
    
    def provision_localized_android_resources(language_tags = self.language_tags_from_locales_api)
      FileUtils.mkdir(output_dir) unless File.exists?(output_dir)
      language_tags.inject([]) do |paths, language_tag|
        language_tag = TripAdvisor::Translation.locale_identifier_to_language_codes_mapping[language_tag] || language_tag
        language_tag.gsub!(/-/,'_')
        language_tag.gsub!(/_/,'-r')
        path = File.join(output_dir, "values-#{language_tag}")
        unless File.exist?(path)
          FileUtils.mkdir(path)
          paths << path
          yield path if block_given?
        end      
        paths
      end
    end
  end
end
